@@ -261,7 +261,15 @@ QPDF_ERROR_CODE qpdf_read(qpdf_data qpdf, char const* filename,
     qpdf->filename = filename;
     qpdf->password = password;
     status = trap_errors(qpdf, &call_read);
-    QTC::TC("qpdf", "qpdf-c called qpdf_read", status);
+    // We no longer have a good way to exercise a file with both
+    // warnings and errors because qpdf is getting much better at
+    // recovering.
+    QTC::TC("qpdf", "qpdf-c called qpdf_read",
+            (status == 0) ? 0
+            : (status & QPDF_WARNINGS) ? 1
+            : (status & QPDF_ERRORS) ? 2 :
+            -1
+        );
     return status;
 }
 
@@ -494,6 +502,30 @@ void qpdf_set_object_stream_mode(qpdf_data qpdf, qpdf_object_stream_e mode)
     qpdf->qpdf_writer->setObjectStreamMode(mode);
 }
 
+void qpdf_set_compress_streams(qpdf_data qpdf, QPDF_BOOL value)
+{
+    QTC::TC("qpdf", "qpdf-c called qpdf_set_compress_streams");
+    qpdf->qpdf_writer->setCompressStreams(value);
+}
+
+void qpdf_set_decode_level(qpdf_data qpdf, qpdf_stream_decode_level_e level)
+{
+    QTC::TC("qpdf", "qpdf-c called qpdf_set_decode_level");
+    qpdf->qpdf_writer->setDecodeLevel(level);
+}
+
+void qpdf_set_preserve_unreferenced_objects(qpdf_data qpdf, QPDF_BOOL value)
+{
+    QTC::TC("qpdf", "qpdf-c called qpdf_set_preserve_unreferenced_objects");
+    qpdf->qpdf_writer->setPreserveUnreferencedObjects(value);
+}
+
+void qpdf_set_newline_before_endstream(qpdf_data qpdf, QPDF_BOOL value)
+{
+    QTC::TC("qpdf", "qpdf-c called qpdf_set_newline_before_endstream");
+    qpdf->qpdf_writer->setNewlineBeforeEndstream(value);
+}
+
 void qpdf_set_stream_data_mode(qpdf_data qpdf, qpdf_stream_data_e mode)
 {
     QTC::TC("qpdf", "qpdf-c called qpdf_set_stream_data_mode");
@@ -512,6 +544,12 @@ void qpdf_set_qdf_mode(qpdf_data qpdf, QPDF_BOOL value)
     qpdf->qpdf_writer->setQDFMode(value);
 }
 
+void qpdf_set_deterministic_ID(qpdf_data qpdf, QPDF_BOOL value)
+{
+    QTC::TC("qpdf", "qpdf-c called qpdf_set_deterministic_ID");
+    qpdf->qpdf_writer->setDeterministicID(value);
+}
+
 void qpdf_set_static_ID(qpdf_data qpdf, QPDF_BOOL value)
 {
     QTC::TC("qpdf", "qpdf-c called qpdf_set_static_ID");
@@ -632,6 +670,6 @@ QPDF_ERROR_CODE qpdf_write(qpdf_data qpdf)
 {
     QPDF_ERROR_CODE status = QPDF_SUCCESS;
     status = trap_errors(qpdf, &call_write);
-    QTC::TC("qpdf", "qpdf-c called qpdf_write", status);
+    QTC::TC("qpdf", "qpdf-c called qpdf_write", (status == 0) ? 0 : 1);
     return status;
 }
